@@ -6,9 +6,9 @@ from .._interp import interp3d
 from ._common import shrink
 
 
-# @jitted(
-#     "Tuple((f8[:, :], i4))(f8[:], f8[:], f8[:], f8[:, :, :], f8[:, :, :], f8[:, :, :], f8, f8, f8, f8, f8, f8, f8, i4, b1)"
-# )
+@jitted(
+    "Tuple((f8[:, :], i4))(f8[:], f8[:], f8[:], f8[:, :, :], f8[:, :, :], f8[:, :, :], f8, f8, f8, f8, f8, f8, f8, i4, b1)"
+)
 def _ray3d(
     z,
     x,
@@ -79,10 +79,13 @@ def _ray3d(
             pcur[2] = min(max(pcur[2], y[0]), y[-1])
 
             if fac < 1.0:
-                # Handle precision issues due to fac
-                pcur[0] = np.round(pcur[0], 8)
-                pcur[1] = np.round(pcur[1], 8)
-                pcur[2] = np.round(pcur[2], 8)
+                # Grid magnetism: handle precision issues due to fac
+                for ix in range(3):
+                    if np.abs(pcur[ix] - lower[ix]) < 1.0e-8:
+                        pcur[ix] = lower[ix]
+
+                    elif np.abs(pcur[ix] - upper[ix]) < 1.0e-8:
+                        pcur[ix] = upper[ix]
 
                 i = np.searchsorted(z, pcur[0], side="right") - 1
                 j = np.searchsorted(x, pcur[1], side="right") - 1
@@ -117,7 +120,7 @@ def _ray3d(
     return ray, count
 
 
-# @jitted(parallel=True)
+@jitted(parallel=True)
 def _ray3d_vectorized(
     z,
     x,
@@ -161,7 +164,7 @@ def _ray3d_vectorized(
     return rays, counts
 
 
-# @jitted
+@jitted
 def ray3d(z, x, y, zgrad, xgrad, ygrad, p, src, stepsize, max_step, honor_grid=False):
     """Perform ray-tracing."""
     if p.ndim == 1:
