@@ -1,4 +1,4 @@
-import numpy
+import numpy as np
 from numba import prange
 
 from .._common import jitted
@@ -12,12 +12,12 @@ def _interp2d(x, y, v, xq, yq, fval):
     if not (condx and condy):
         return fval
 
-    nx, ny = numpy.shape(v)
+    nx, ny = np.shape(v)
     nx -= 1
     ny -= 1
 
-    i1 = numpy.searchsorted(x, xq, side="right") - 1
-    j1 = numpy.searchsorted(y, yq, side="right") - 1
+    i1 = np.searchsorted(x, xq, side="right") - 1
+    j1 = np.searchsorted(y, yq, side="right") - 1
     i2 = i1 + 1
     j2 = j1 + 1
 
@@ -65,11 +65,11 @@ def _interp2d(x, y, v, xq, yq, fval):
         v12 = v[i1, j2]
         v22 = v[i2, j2]
 
-    vq = v11 * numpy.abs((x2 - xq) * (y2 - yq))
-    vq += v21 * numpy.abs((x1 - xq) * (y2 - yq))
-    vq += v12 * numpy.abs((x2 - xq) * (y1 - yq))
-    vq += v22 * numpy.abs((x1 - xq) * (y1 - yq))
-    vq /= numpy.abs((x2 - x1) * (y2 - y1))
+    vq = v11 * np.abs((x2 - xq) * (y2 - yq))
+    vq += v21 * np.abs((x1 - xq) * (y2 - yq))
+    vq += v12 * np.abs((x2 - xq) * (y1 - yq))
+    vq += v22 * np.abs((x1 - xq) * (y1 - yq))
+    vq /= np.abs((x2 - x1) * (y2 - y1))
 
     return vq
 
@@ -78,7 +78,7 @@ def _interp2d(x, y, v, xq, yq, fval):
 def _interp2d_vectorized(x, y, v, xq, yq, fval):
     """Perform bilinear interpolation for different points."""
     nq = len(xq)
-    out = numpy.empty(nq, dtype=numpy.float64)
+    out = np.empty(nq, dtype=np.float64)
     for i in prange(nq):
         out[i] = _interp2d(x, y, v, xq[i], yq[i], fval)
 
@@ -86,7 +86,7 @@ def _interp2d_vectorized(x, y, v, xq, yq, fval):
 
 
 @jitted
-def interp2d(x, y, v, q, fval=numpy.nan):
+def interp2d(x, y, v, q, fval=np.nan):
     """Perform bilinear interpolation."""
     if q.ndim == 1:
         return _interp2d(x, y, v, q[0], q[1], fval)
